@@ -15,7 +15,7 @@ from pathlib import Path
 import pandas as pd
 from nanome.common.global_config import set_log_debug_level, current_time_str
 
-NANOME_VERSION = "2.0.3"
+NANOME_VERSION = "2.0.4"
 
 # define the small error of 0 and 1, for fully-meth and unmeth eval
 EPSLONG = 1e-5
@@ -88,13 +88,6 @@ discord_tagname = 'Discordant'
 
 default_config_name = 'nanome_genome_annotation.csv'
 
-xgboost_mode_base_dir = os.path.join(Path(__file__).parent.parent, 'xgboost', 'trained_model')
-
-nanome_model_dict = {
-    "NA12878_XGBoostNA2T": 'NANOME_NA12878_train1.0_megalodon_deepsignal_XGBoostNA2T_model.pkl',
-    "NA12878_XGBoostNA3T": 'NANOME_NA12878_train1.0_nanopolish_megalodon_deepsignal_XGBoostNA3T_niter10_model.pkl',
-}
-
 
 def load_genome_annotation_config(verbose=False):
     ## config file can be located at pwd, then the module dir
